pub struct Error { /* private fields */ }Implementations
Sourceimpl Error
impl Error
Sourcepub fn marshalling(message: impl Into<String>) -> Self
pub fn marshalling(message: impl Into<String>) -> Self
Create an Error for failure to marshall a message from a Smithy shape
Sourcepub fn unmarshalling(message: impl Into<String>) -> Self
pub fn unmarshalling(message: impl Into<String>) -> Self
Create an Error for failure to unmarshall a message into a Smithy shape
Sourcepub fn is_invalid_message(&self) -> bool
pub fn is_invalid_message(&self) -> bool
Returns true if the error is one generated during serialization