pub trait SignMessage: Debug {
// Required methods
fn sign(
&mut self,
message: Message,
) -> Result<Message, Box<dyn Error + Sync + Send>>;
fn sign_empty(
&mut self,
) -> Option<Result<Message, Box<dyn Error + Sync + Send>>>;
}Expand description
Signs an Event Stream message.
Required Methods
Sourcefn sign(
&mut self,
message: Message,
) -> Result<Message, Box<dyn Error + Sync + Send>>
fn sign( &mut self, message: Message, ) -> Result<Message, Box<dyn Error + Sync + Send>>
Signs a message, returning the signed version.
Sourcefn sign_empty(
&mut self,
) -> Option<Result<Message, Box<dyn Error + Sync + Send>>>
fn sign_empty( &mut self, ) -> Option<Result<Message, Box<dyn Error + Sync + Send>>>
SigV4 requires an empty last signed message to be sent.
Other protocols do not require one.
Return Some(_) to send a signed last empty message, before completing the stream.
Return None to not send one and terminate the stream immediately.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".