SignMessage

Trait SignMessage 

pub trait SignMessage: Debug {
    // Required methods
    fn sign(
        &mut self,
        message: Message,
    ) -> Result<Message, Box<dyn Error + Send + Sync>>;
    fn sign_empty(
        &mut self,
    ) -> Option<Result<Message, Box<dyn Error + Send + Sync>>>;
}
Signs an Event Stream message.

Required Methods

fn sign( &mut self, message: Message, ) -> Result<Message, Box<dyn Error + Send + Sync>>

Signs a message, returning the signed version.

fn sign_empty( &mut self, ) -> Option<Result<Message, Box<dyn Error + Send + Sync>>>

SigV4 requires an empty last signed message to be sent. Other protocols do not require one. Return Some(_) to send a signed last empty message, before completing the stream. Return None to not send one and terminate the stream immediately.

Implementors